@@ -1,33 +1,12 @@
 # test.gbm.R: gbm tests for plotmo and plotres
 
+source("test.prolog.R")
 library(gbm)
 library(rpart.plot) # for ptitanic, want data with NAs for testing
 library(plotmo)
 library(earth) # for ozone1
 data(ptitanic)
-set.seed(2016)
-options(warn=1) # print warnings as they occur
-if(!interactive())
-    postscript(paper="letter")
 
-printf <- function(format, ...) cat(sprintf(format, ...), sep="") # like c printf
-
-strip.space <- function(s) gsub("[ \t\n]", "", s)
-
-# test that we got an error as expected from a try() call
-expect.err <- function(object, expected.msg="")
-{
-    if(class(object)[1] == "try-error") {
-        msg <- attr(object, "condition")$message[1]
-        if(length(grep(expected.msg, msg, fixed=TRUE)))
-            cat("Got error as expected from ",
-                deparse(substitute(object)), "\n", sep="")
-        else
-            stop(sprintf("Expected: %s\n  Got:      %s",
-                         expected.msg, substr(msg[1], 1, 1000)))
-    } else
-        stop("Did not get expected error: ", expected.msg)
-}
 cat("--- distribution=\"gaussian\", formula interface ----------------------------------\n")
 
 set.seed(2016)
@@ -566,7 +545,4 @@ plot_gbm(gbm.iris)
 # print(summary(gbmt.bernoulli)) # will also plot
 # par(old.par)
 
-if(!interactive()) {
-    dev.off()         # finish postscript plot
-    q(runLast=FALSE)  # needed else R prints the time on exit (R2.5 and higher) which messes up the diffs
-}
+source("test.epilog.R")
